#' @importFrom Rcpp sourceCpp
#' @useDynLib squat, .registration = TRUE
#'
#' @keywords internal
"_PACKAGE"
